@@ -1,21 +1,35 @@
-"""An example script that demonstrates handling various events from Chatubate."""
+# /// script
+# requires-python = ">=3.12"
+# dependencies = [
+#     "cb-events",
+#     "python-dotenv",
+#     "rich",
+# ]
+# ///
+
+"""Example script demonstrating event handling from Chaturbate."""
 
 import asyncio
 import contextlib
 import os
 
+from dotenv import load_dotenv
+from rich import print  # noqa: A004
+
 from cb_events import (
+    ClientConfig,
     Event,
     EventClient,
-    EventClientConfig,
-    EventRouter,
     EventType,
+    Router,
 )
 
+load_dotenv()
+
 username = os.getenv("CB_USERNAME", "")
 token = os.getenv("CB_TOKEN", "")
 
-router = EventRouter()
+router = Router()
 
 
 @router.on(EventType.BROADCAST_START)
@@ -69,7 +83,9 @@ async def handle_fanclub_join(event: Event) -> None:
 async def handle_chat_message(event: Event) -> None:
     """Handle chat message events."""
     if event.user and event.message:
-        print(f"{event.user.username} sent chat message: {event.message.message}")
+        print(
+            f"{event.user.username} sent chat message: {event.message.message}"
+        )
 
 
 @router.on(EventType.PRIVATE_MESSAGE)
@@ -87,7 +103,9 @@ async def handle_tip(event: Event) -> None:
     """Handle tip events."""
     if event.user and event.tip:
         anon_text = "anonymously " if event.tip.is_anon else ""
-        clean_message = event.tip.message.removeprefix("| ") if event.tip.message else ""
+        clean_message = (
+            event.tip.message.removeprefix("| ") if event.tip.message else ""
+        )
         message_text = f"with message: {clean_message}" if clean_message else ""
         print(
             f"{event.user.username} sent {event.tip.tokens} tokens "
@@ -107,7 +125,10 @@ async def handle_media_purchase(event: Event) -> None:
     """Handle media purchase events."""
     if event.user and "media" in event.data:
         media = event.data["media"]
-        print(f"{event.user.username} purchased {media['type']} set: {media['name']}")
+        print(
+            f"{event.user.username} purchased {media['type']} "
+            f"set: {media['name']}"
+        )
 
 
 @router.on_any()
@@ -133,7 +154,7 @@ async def handle_unknown_event(event: Event) -> None:
 
 async def main() -> None:
     """Set up event handlers and start listening for events."""
-    config = EventClientConfig(use_testbed=True)
+    config = ClientConfig(use_testbed=True)
 
     async with EventClient(username, token, config=config) as client:
         print("Listening for events... (Ctrl+C to stop)")
