@@ -1,8 +1,3 @@
-# pyright: reportMissingParameterType=false
-# pyright: reportUnknownParameterType=false
-# pyright: reportUnknownArgumentType=false
-# pyright: reportUnknownMemberType=false
-
 """Initialization tests for :class:`cb_events.EventClient`."""
 
 import pytest
@@ -23,13 +18,15 @@ def test_token_masking_in_repr() -> None:
 @pytest.mark.parametrize(
     ("username", "token", "message"),
     [
-        ("", "token", "Username cannot be empty or contain"),
-        (" user ", "token", "Username cannot be empty or contain"),
-        ("user", "", "Token cannot be empty or contain"),
-        ("user", " token ", "Token cannot be empty or contain"),
+        ("", "token", "Username must not be empty or contain"),
+        (" user ", "token", "Username must not be empty or contain"),
+        ("user", "", "Token must not be empty or contain"),
+        ("user", " token ", "Token must not be empty or contain"),
     ],
 )
-def test_reject_invalid_credentials(username: str, token: str, message: str) -> None:
+def test_reject_invalid_credentials(
+    username: str, token: str, message: str
+) -> None:
     """Invalid credentials should raise an ``AuthError`` with guidance."""
     with pytest.raises(AuthError, match=message):
         EventClient(username, token)
