@@ -1,9 +1,3 @@
-# pyright: reportMissingParameterType=false
-# pyright: reportUnknownParameterType=false
-# pyright: reportUnknownArgumentType=false
-# pyright: reportUnknownMemberType=false
-# pyright: reportUnknownVariableType=false
-
 """Tests for exception hierarchy and messaging."""
 
 from cb_events import AuthError, EventsError
@@ -25,25 +19,24 @@ def test_events_error_with_status_code() -> None:
     assert error.status_code == 500
 
 
-def test_events_error_repr_includes_details() -> None:
-    """``repr`` should include all relevant fields when present."""
-    error = EventsError("Test error", status_code=404, response_text="Not found response")
-    repr_str = repr(error)
+def test_events_error_attributes() -> None:
+    """Error attributes should be accessible."""
+    error = EventsError(
+        "Test error", status_code=404, response_text="Not found response"
+    )
 
-    assert "EventsError" in repr_str
-    assert "Test error" in repr_str
-    assert "status_code=404" in repr_str
-    assert "response_text=" in repr_str
+    assert error.status_code == 404
+    assert error.response_text == "Not found response"
+    assert str(error) == "Test error (HTTP 404)"
 
 
-def test_events_error_repr_minimal() -> None:
-    """``repr`` should also work when only the message is provided."""
+def test_events_error_minimal() -> None:
+    """Error should work with only message."""
     error = EventsError("Simple error")
-    repr_str = repr(error)
 
-    assert "EventsError" in repr_str
-    assert "Simple error" in repr_str
-    assert "status_code" not in repr_str
+    assert error.status_code is None
+    assert error.response_text is None
+    assert str(error) == "Simple error"
 
 
 def test_auth_error_inherits_events_error() -> None:
